@@ -1,4 +1,3 @@
-/* $Id: idxset.c,v 1.21 2012/07/29 15:09:27 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: idxset.c                                                      */
@@ -8,7 +7,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2017 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -134,7 +133,7 @@ void idxset_print(FILE* fp, const IdxSet* idxset)
    tuple_print(fp, idxset->tuple);
    fputc('\n', fp);
    set_print(fp, idxset->set);
-   fprintf(fp, "\nAddr-Lexpr: %ld\n", (long)idxset->lexpr);
+   fprintf(fp, "\nAddr-Lexpr: %p\n", (void*)idxset->lexpr);
 }
 
 
