@@ -1,4 +1,3 @@
-/* $Id: local.c,v 1.23 2012/07/29 15:09:27 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: local.c                                                       */
@@ -8,7 +7,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2017 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -122,7 +121,6 @@ const Elem* local_lookup(const char* name)
 
 void local_install_tuple(const Tuple* pattern, const Tuple* values)
 {
-   const Elem* elem;
    const char* name;
    int         i;
    
@@ -135,7 +133,7 @@ void local_install_tuple(const Tuple* pattern, const Tuple* values)
    
    for(i = 0; i < tuple_get_dim(pattern); i++)
    {
-      elem = tuple_get_elem(pattern, i);
+      const Elem* elem = tuple_get_elem(pattern, i);
 
       if (elem_get_type(elem) == ELEM_NAME)
       {
