@@ -1,4 +1,3 @@
-/* $Id: setmulti.c,v 1.26 2012/07/29 15:09:30 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: setmulti.c                                                    */
@@ -8,7 +7,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2017 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -31,6 +30,7 @@
 #include <string.h>
 #include <assert.h>
 
+#include "lint.h"
 #include "bool.h"
 #include "mshell.h"
 #include "ratlptypes.h"
@@ -92,11 +92,10 @@ static int subset_cmp(const void* a, const void* b)
    const int* bb = (const int*)b;
 
    int i;
-   int d;
 
    for(i = 0; i < cmp_dim; i++)
    {
-      d = aa[i] - bb[i];
+      int d = aa[i] - bb[i];
 
       if (d != 0)
          return d;
@@ -318,7 +317,6 @@ static int subset_idx_cmp(const void* a, const void* b)
    const int* key    = (const int*)a;
    const int* subset = (const int*)b;
    int        i;
-   int        d;
    
    assert(key    != NULL);
    assert(subset != NULL);
@@ -327,7 +325,7 @@ static int subset_idx_cmp(const void* a, const void* b)
 
    for(i = 0; i < cmp_dim; i++)
    {
-      d = key[i] - subset[i];
+      int d = key[i] - subset[i];
 
       if (d != 0)
          return d;
@@ -645,7 +643,7 @@ static Bool set_multi_iter_next(
  * -------------------------------------------------------------------------
  */
 /*ARGSUSED*/
-static void set_multi_iter_exit(SetIter* iter, const Set* set)
+static void set_multi_iter_exit(SetIter* iter, UNUSED const Set* set)
 {
    assert(set_multi_iter_is_valid(iter));
 
@@ -662,7 +660,7 @@ static void set_multi_iter_exit(SetIter* iter, const Set* set)
  * -------------------------------------------------------------------------
  */
 /*ARGSUSED*/
-static void set_multi_iter_reset(SetIter* iter, const Set* set)
+static void set_multi_iter_reset(SetIter* iter, UNUSED const Set* set)
 {
    assert(set_multi_iter_is_valid(iter));
    
