@@ -1,4 +1,3 @@
-/* $Id: tuple.c,v 1.35 2012/07/29 15:09:30 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: tuple.c                                                       */
@@ -8,7 +7,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2017 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -83,8 +82,6 @@ Tuple* tuple_new(int dim)
 
 void tuple_free(Tuple* tuple)
 {
-   int i;
-   
    assert(tuple_is_valid(tuple));
    assert(tuple->element != NULL);
 
@@ -92,6 +89,8 @@ void tuple_free(Tuple* tuple)
 
    if (tuple->refc == 0)
    {
+      int i;
+   
       for(i = 0; i < tuple->dim; i++)
          if (tuple->element[i] != NULL)
             elem_free(tuple->element[i]);
@@ -284,8 +283,6 @@ char* tuple_tostr(const Tuple* tuple)
    size_t  size = TUPLE_STR_SIZE;
    size_t  len  = 1; /* one for the zero '\0' */
    char*   str  = malloc(size);
-   char*   selem;
-   size_t  selemlen;
    int     i;
    
    assert(tuple_is_valid(tuple));
@@ -295,8 +292,8 @@ char* tuple_tostr(const Tuple* tuple)
    
    for(i = 0; i < tuple->dim; i++)
    {
-      selem    = elem_tostr(tuple->element[i]);
-      selemlen = strlen(selem) + 1;
+      char*  selem    = elem_tostr(tuple->element[i]);
+      size_t selemlen = strlen(selem) + 1;
 
       if (len + selemlen >= size)
       {
